@@ -1,4 +1,4 @@
-# Copyright (c) 2014, Riverbank Computing Limited
+# Copyright (c) 2017, Riverbank Computing Limited
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -24,7 +24,8 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 
-from PyQt5.QtWidgets import QGroupBox, QMessageBox, QVBoxLayout, QWidget
+from PyQt5.QtWidgets import (QGroupBox, QHBoxLayout, QMessageBox, QPushButton,
+        QVBoxLayout, QWidget)
 
 from .better_form import BetterForm
 from .filename_editor import FilenameEditor
@@ -52,7 +53,6 @@ class LocationsPage(QWidget):
             self._target_inc_edit.set_project(value)
             self._target_lib_edit.set_project(value)
             self._target_stdlib_edit.set_project(value)
-            self._build_edit.set_project(value)
             self._update_page()
 
     def __init__(self):
@@ -69,13 +69,14 @@ class LocationsPage(QWidget):
         self._host_interp_edit = FilenameEditor("Host Interpreter",
                 placeholderText="Interpreter executable",
                 whatsThis="The name of the host interpreter's executable. "
-                        "This must be on PATH or be an absolute pathname.",
+                        "This must be on <tt>PATH</tt> or be an absolute "
+                        "pathname.",
                 textEdited=self._host_interp_changed)
         py_host_layout.addRow("Interpreter", self._host_interp_edit)
 
         self._source_edit = FilenameEditor("Source Directory",
                 placeholderText="Source directory name",
-                whatsThis="The name of the source directory.",
+                whatsThis="The name of the Python source directory.",
                 textEdited=self._source_changed, directory=True)
         py_host_layout.addRow("Source directory", self._source_edit)
 
@@ -99,41 +100,32 @@ class LocationsPage(QWidget):
         self._target_stdlib_edit = FilenameEditor(
                 "Target Standard Library Directory",
                 placeholderText="Standard library directory name",
-                whatsThis="The target interpreter's standard library directory.",
+                whatsThis="The target interpreter's standard library "
+                        "directory.",
                 textEdited=self._target_stdlib_changed, directory=True)
         py_target_layout.addRow("Standard library directory",
                 self._target_stdlib_edit)
 
         py_target_group.setLayout(py_target_layout)
 
-        others_group = QGroupBox("Other Locations")
-        others_layout = BetterForm()
+        set_defaults = QPushButton("Set defaults",
+                whatsThis="Set the locations to their default values. These "
+                        "are those used by <tt>pyqtdeploy-sysroot</tt>.",
+                clicked=self._set_defaults)
 
-        self._build_edit = FilenameEditor("Build Directory",
-                placeholderText="Build directory name",
-                whatsThis="The name of the build directory. The directory "
-                        "will be created automatically if necessary.",
-                textEdited=self._build_changed, directory=True)
-        others_layout.addRow("Build directory", self._build_edit)
-
-        self._qmake_edit = FilenameEditor("qmake",
-                placeholderText="qmake executable",
-                whatsThis="The name of the qmake executable. This must be on "
-                        "PATH or be an absolute pathname.",
-                textEdited=self._qmake_changed)
-        others_layout.addRow("qmake", self._qmake_edit)
-
-        others_group.setLayout(others_layout)
+        button_layout = QHBoxLayout()
+        button_layout.addStretch()
+        button_layout.addWidget(set_defaults)
 
         layout = QVBoxLayout()
         layout.addWidget(py_host_group)
         layout.addWidget(py_target_group)
-        layout.addWidget(others_group)
         layout.addStretch()
+        layout.addLayout(button_layout)
 
         self.setLayout(layout)
 
-        BetterForm.align_forms(py_host_layout, py_target_layout, others_layout)
+        BetterForm.align_forms(py_host_layout, py_target_layout)
 
     def _update_page(self):
         """ Update the page using the current project. """
@@ -145,31 +137,33 @@ class LocationsPage(QWidget):
         self._target_inc_edit.setText(project.python_target_include_dir)
         self._target_lib_edit.setText(project.python_target_library)
         self._target_stdlib_edit.setText(project.python_target_stdlib_dir)
-        self._build_edit.setText(project.build_dir)
-        self._qmake_edit.setText(project.qmake)
 
     def _host_interp_changed(self, value):
         """ Invoked when the user edits the host interpreter name. """
 
         self.project.python_host_interpreter = value
+        self.project.using_default_locations = False
         self.project.modified = True
 
     def _source_changed(self, value):
         """ Invoked when the user edits the source directory name. """
 
         self.project.python_source_dir = value
+        self.project.using_default_locations = False
         self.project.modified = True
 
     def _target_inc_changed(self, value):
         """ Invoked when the user edits the target include directory name. """
 
         self.project.python_target_include_dir = value
+        self.project.using_default_locations = False
         self.project.modified = True
 
     def _target_lib_changed(self, value):
         """ Invoked when the user edits the target Python library name. """
 
         self.project.python_target_library = value
+        self.project.using_default_locations = False
         self.project.modified = True
 
     def _target_stdlib_changed(self, value):
@@ -178,16 +172,12 @@ class LocationsPage(QWidget):
         """
 
         self.project.python_target_stdlib_dir = value
+        self.project.using_default_locations = False
         self.project.modified = True
 
-    def _build_changed(self, value):
-        """ Invoked when the user edits the build directory name. """
+    def _set_defaults(self):
+        """ Invoked when the user clicks to set the default locations. """
 
-        self.project.build_dir = value
-        self.project.modified = True
-
-    def _qmake_changed(self, value):
-        """ Invoked when the user edits the qmake name. """
-
-        self.project.qmake = value
+        self.project.set_default_locations()
+        self._update_page()
         self.project.modified = True
