@@ -1,4 +1,4 @@
-# Copyright (c) 2014, Riverbank Computing Limited
+# Copyright (c) 2018, Riverbank Computing Limited
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,29 +32,62 @@ class ExternalLibraryMetadata:
     standard library.
     """
 
-    def __init__(self, name, libs, user_name):
+    def __init__(self, name, libs, user_name, defines=''):
         """ Initialise the object. """
 
         # The well known internal identifier of the library.
         self.name = name
 
+        # The default DEFINES to add to the .pro file.
+        self.defines = defines
+
+        # The default INCLUDEPATH to add to the .pro file.
+        self.includepath = '$SYSROOT/include'
+
         # The default LIBS to add to the .pro file.
-        self.libs = libs
+        self._libs = libs
 
         # The name of the library as presented to the user.
         self.user_name = user_name
 
+    def get_libs(self, target):
+        """ Get the target specific libs.  If the value is empty then the
+        target doesn't support the library.
+        """
+
+        if isinstance(self._libs, str):
+            # The libs are not target specific.
+            libs = self._libs
+        else:
+            # See if there is a target specific value.
+            libs = self._libs.get(target)
+
+            if libs is None:
+                # Get the default value.
+                libs = self._libs.get('')
+
+        if libs != '':
+            libs = '-L$SYSROOT/lib ' + libs
+
+        return libs
+
 
 # The meta-data for each external library that might be needed by the Python
-# standard library..
+# standard library.
 external_libraries_metadata = (
-    ExternalLibraryMetadata('ssl', '-lssl -lcrypto', "SSL encryption"),
+    ExternalLibraryMetadata('ssl',
+            # Note that for OpenSSL v1.0 (ie. Python v3.6 and earlier) it
+            # should be '-lssleay32 -llibeay32'.
+            {'win': '-llibssl -llibcrypto', '': '-lssl -lcrypto'},
+            "SSL encryption"),
+    ExternalLibraryMetadata('zlib', {'win': '-lzlib', '': '-lz'},
+            "zlib compression"),
     ExternalLibraryMetadata('bz2', '-lbz2', "bz2 compression"),
     ExternalLibraryMetadata('lzma', '-llzma', "LZMA compression"),
-    ExternalLibraryMetadata('zlib', '-lz', "zlib compression"),
     ExternalLibraryMetadata('bsddb', '-ldb', "BSD db database"),
     ExternalLibraryMetadata('dbm', '-lndbm', "dbm database"),
     ExternalLibraryMetadata('gdbm', '-lgdbm', "gdbm database"),
+    ExternalLibraryMetadata('sqlite3', '-lsqlite3', "SQLite database"),
     ExternalLibraryMetadata('readline', '-lreadline -ltermcap', "readline"),
     ExternalLibraryMetadata('curses', '-lcurses -ltermcap', "Curses"),
     ExternalLibraryMetadata('panel', '-lpanel -lcurses', "Curses panel"),
